@@ -54,6 +54,7 @@
 #' @template param_term_evals
 #' @template param_term_time
 #' @template param_search_space
+#' @template param_internal_search_space
 #' @template param_store_benchmark_result
 #' @template param_store_models
 #' @template param_check_values
@@ -99,6 +100,7 @@ tune = function(
   terminator = NULL,
   search_space = NULL,
   store_benchmark_result = TRUE,
+  internal_search_space = NULL,
   store_models = FALSE,
   check_values = FALSE,
   callbacks = NULL,
@@ -116,11 +118,13 @@ tune = function(
       measures,
       terminator = terminator,
       search_space = search_space,
+      internal_search_space = internal_search_space,
       store_benchmark_result = store_benchmark_result,
       store_models = store_models,
       check_values = check_values,
       callbacks = callbacks,
-      rush = rush)
+      rush = rush
+      )
   } else {
     TuningInstance = if (is.null(measures) || inherits(measures, "Measure")) TuningInstanceBatchSingleCrit else TuningInstanceBatchMultiCrit
     TuningInstance$new(
@@ -130,6 +134,7 @@ tune = function(
       measures,
       terminator = terminator,
       search_space = search_space,
+      internal_search_space = internal_search_space,
       store_benchmark_result = store_benchmark_result,
       store_models = store_models,
       check_values = check_values,
